@@ -185,7 +185,20 @@ set_profile_tone_value(const gchar* tone, GtkWidget* button, GtkListStore* list_
 {
   GtkTreeIter iter;
   gchar* display_value = get_display_value(tone, list_store, &iter);
-  hildon_button_set_value(HILDON_BUTTON(button), display_value);
+  
+  if (strlen(display_value) > 29)
+  {
+    gchar* short_display_value = g_strndup(display_value, 29);
+    short_display_value[28] = '.';
+    short_display_value[27] = '.';
+    short_display_value[26] = '.';
+    hildon_button_set_value(HILDON_BUTTON(button), short_display_value);
+    g_free(short_display_value);
+  }
+  else
+  {
+    hildon_button_set_value(HILDON_BUTTON(button), display_value);
+  }
   g_free(display_value);
 }
 
@@ -340,17 +353,15 @@ void add_tone_to_list_store(GtkButton* button, GtkWidget* selector)
   parent = gtk_widget_get_parent(parent);
   dialog = hildon_file_chooser_dialog_new(GTK_WINDOW(parent),
 					  GTK_FILE_CHOOSER_ACTION_OPEN);
+  g_object_set(dialog, "empty-text", dgettext("osso-profiles", "profi_va_select_object_no_sound_clips"), NULL);
+  gtk_window_set_title(GTK_WINDOW(dialog), dgettext("osso-profiles", "profi_ti_open_sound_clip"));
+
   GtkFileFilter* fileFilter = gtk_file_filter_new();
-  gtk_file_filter_add_mime_type(fileFilter, "audio/mpeg");
-  gtk_file_filter_add_mime_type(fileFilter, "audio/x-wav");
-  //  gtk_file_filter_add_mime_type(fileFilter, "audio/midi");
-  gtk_file_filter_add_mime_type(fileFilter, "audio/mp4");
-  gtk_file_filter_add_mime_type(fileFilter, "audio/aac");
-  gtk_file_filter_add_mime_type(fileFilter, "audio/ogg");
+  gtk_file_filter_add_mime_type(fileFilter, "audio/*");
+  gtk_file_chooser_add_filter(GTK_FILE_CHOOSER(dialog), fileFilter);
   gtk_file_chooser_set_filter(GTK_FILE_CHOOSER(dialog), fileFilter);
 
-
-  gtk_widget_show_all(GTK_WIDGET(dialog));
+  gtk_file_chooser_set_current_folder(GTK_FILE_CHOOSER(dialog), "/home/user/MyDocs/.sounds");
   
   int ret = gtk_dialog_run(GTK_DIALOG(dialog));
   if(ret == GTK_RESPONSE_OK)
@@ -380,6 +391,29 @@ play_sound_sample(HildonTouchSelector* selector, gint column, editor_data_t* use
   play_sound(list_value, user_data);
 }
 
+static const gchar*
+get_tone_selector_title(editor_data_t* data, GtkWidget* button)
+{
+  if (data == NULL || button == data->ringtoneButton)
+  {
+    dgettext("osso-profiles", "profi_ti_ringing_tone");
+  }
+  else if (button == data->smstoneButton)
+  {
+    return dgettext("osso-profiles", "profi_ti_sub_text_message_tone");
+  }
+  else if (button == data->imtoneButton)
+  {
+    return dgettext("osso-profiles", "profi_ti_instant_messaging_tone");
+  }
+  else if (button == data->emailtoneButton)
+  {
+    return dgettext("osso-profiles", "profi_ti_email_alert_tone");
+  }  
+
+  g_return_val_if_reached(dgettext("osso-profiles", "profi_ti_ringing_tone"));
+}
+
 void
 show_tone_selector(GtkListStore* list_store, GtkWidget* button, GtkWidget* selector, editor_data_t* data)
 {
@@ -394,17 +428,15 @@ show_tone_selector(GtkListStore* list_store, GtkWidget* button, GtkWidget* selec
 
 
   int sound_handler_id = g_signal_connect(selector, "changed", G_CALLBACK(play_sound_sample), data);
-  GtkWidget* dialog = gtk_dialog_new_with_buttons(dgettext("osso-profiles", "profi_fi_ringingtone_tone"),
+  GtkWidget* dialog = gtk_dialog_new_with_buttons(get_tone_selector_title(data, button),
 						  NULL,
 						  GTK_DIALOG_MODAL,
-						  dgettext("hildon-libs", "wdgt_bd_save"),
-						  GTK_RESPONSE_OK,
 						  NULL);
-  more_button = hildon_button_new(HILDON_SIZE_AUTO,
-				  HILDON_BUTTON_ARRANGEMENT_VERTICAL);
+  more_button = hildon_gtk_button_new(HILDON_SIZE_AUTO_WIDTH | HILDON_SIZE_FINGER_HEIGHT);
   gtk_button_set_label(GTK_BUTTON(more_button), dgettext("hildon-libs", "wdgt_bd_add"));
   gtk_container_add(GTK_CONTAINER(gtk_dialog_get_action_area(GTK_DIALOG(dialog))), more_button);
   g_signal_connect(more_button, "clicked", G_CALLBACK(add_tone_to_list_store), selector);
+  (void) gtk_dialog_add_button(GTK_DIALOG(dialog), dgettext("hildon-libs", "wdgt_bd_done"), GTK_RESPONSE_OK);
   gtk_container_add(GTK_CONTAINER(GTK_DIALOG(dialog)->vbox), selector);
 
   gtk_window_set_default_size(GTK_WINDOW(dialog), -1, 300);  
@@ -441,6 +473,7 @@ create_tone_selector_widget(GtkListStore* list_store)
  					       renderer, 
  					       "text", 0, NULL); 
 
+  g_object_set (G_OBJECT(renderer), "width", 1, "xalign", 0.5f, NULL);
   g_object_set(G_OBJECT(column), 
  	       "text-column", 0, 
  	       NULL); 
@@ -507,8 +540,7 @@ init_editor_tone_selector_widgets(editor_data_t* app_data)
   hildon_button_set_title(HILDON_BUTTON(app_data->smstoneButton),
 			  dgettext("osso-profiles", "profi_ti_sub_text_message_tone"));
   hildon_button_set_title(HILDON_BUTTON(app_data->imtoneButton),
-			  dgettext("osso-profiles", "profi_ti_instant_messaging_tone"));
-    
+			  dgettext("osso-profiles", "profi_fi_instant_messaging_alert_tone"));    
   hildon_button_set_alignment(HILDON_BUTTON(app_data->ringtoneButton),
 			      0, 0,
 			      1, 1);
@@ -576,7 +608,8 @@ create_sound_level_widget(GtkListStore* list_store, gchar* title)
 					       GTK_TREE_MODEL(list_store), renderer,
 					       "text", 0, NULL);
   g_object_set(G_OBJECT(column), "text-column", 0, NULL);
-  
+ 
+  g_object_set (G_OBJECT(renderer), "width", 1, "xalign", 0.5f, NULL);  
   hildon_button_set_title(HILDON_BUTTON(widget),
 			  title);
   hildon_picker_button_set_selector(HILDON_PICKER_BUTTON(widget), 
@@ -762,9 +795,9 @@ layout_dialog_widgets(const gchar* profile_name, editor_data_t* data, GtkWidget*
     gtk_container_add(GTK_CONTAINER(content_area), smsBox);
     gtk_container_add(GTK_CONTAINER(content_area), imBox);
     gtk_container_add(GTK_CONTAINER(content_area), emailBox);
+    gtk_container_add(GTK_CONTAINER(content_area), data->systemsoundLevelButton);
     gtk_container_add(GTK_CONTAINER(content_area), data->keypadsoundLevelButton);
     gtk_container_add(GTK_CONTAINER(content_area), data->touchscreensoundLevelButton);
-    gtk_container_add(GTK_CONTAINER(content_area), data->systemsoundLevelButton);
     pannable_area = hildon_pannable_area_new();
     hildon_pannable_area_add_with_viewport(HILDON_PANNABLE_AREA(pannable_area), content_area);
     gtk_container_add(GTK_CONTAINER(gtk_dialog_get_content_area(GTK_DIALOG(dialog))),
