@@ -34,6 +34,7 @@
 #define 	PROFILED_PATH   "/com/nokia/profiled"
 #define 	PROFILED_INTERFACE   "com.nokia.profiled"
 #define 	PROFILED_CHANGED   "profile_changed"
+
 struct _ProfilesxStatusPluginPrivate
 {
   GtkWidget* button;
@@ -44,7 +45,7 @@ struct _ProfilesxStatusPluginPrivate
 HD_DEFINE_PLUGIN_MODULE(ProfilesxStatusPlugin, profilesx_status_plugin, HD_TYPE_STATUS_MENU_ITEM);
 
 
-gchar* get_profile_display_name(const gchar* profile_name)
+const gchar* get_profile_display_name(const gchar* profile_name)
 {
   if(g_strcmp0(profile_name, "silent")==0)
   {
@@ -56,7 +57,7 @@ gchar* get_profile_display_name(const gchar* profile_name)
   }
   else
   {
-    return g_strdup(profile_name);
+    return profile_name;
   }
 }
 
@@ -97,11 +98,13 @@ show_profile_selection_dlg(GtkButton* button, ProfilesxStatusPlugin* plugin)
 						  dgettext("hildon-libs", "wdgt_bd_done"), GTK_RESPONSE_OK, NULL);
   gtk_window_set_default_size(GTK_WINDOW(dialog), -1, 300);  
 
-  content_area = gtk_vbox_new(FALSE, 3);
+  content_area = gtk_hbox_new(TRUE, 3);
   pannable_area = hildon_pannable_area_new();
   gchar** profileList = profile_get_profiles();
   GtkWidget** vibs;
   GtkWidget* previousRadioButton = NULL;
+  GtkWidget* left_box = gtk_vbox_new(FALSE, 0);
+  GtkWidget* right_box = gtk_vbox_new(FALSE, 0);
   if(profileList)
   {
     gint profile_list_length = g_strv_length(profileList);
@@ -115,7 +118,6 @@ show_profile_selection_dlg(GtkButton* button, ProfilesxStatusPlugin* plugin)
 	*profilePtr;
 	profilePtr++)
     {
-      GtkWidget* hbox = gtk_hbox_new(FALSE, 3);
       GtkWidget* button = hildon_gtk_radio_button_new_from_widget(HILDON_SIZE_FINGER_HEIGHT,
 								  GTK_RADIO_BUTTON(previousRadioButton));
       gtk_button_set_label(GTK_BUTTON(button),
@@ -135,12 +137,14 @@ show_profile_selection_dlg(GtkButton* button, ProfilesxStatusPlugin* plugin)
       idx++;
       gtk_button_set_label(GTK_BUTTON(vib_button),
 			   dgettext("osso-profiles", "profi_fi_general_vibrate"));
-      gtk_box_pack_start(GTK_BOX(hbox), button, TRUE, TRUE, 3);
-      gtk_box_pack_end(GTK_BOX(hbox), vib_button, FALSE, FALSE, 0);
-      gtk_box_pack_start(GTK_BOX(content_area), hbox, FALSE, FALSE, 3);
+
+      gtk_box_pack_start(GTK_BOX(left_box), button, FALSE, FALSE, 3);
+      gtk_box_pack_start(GTK_BOX(right_box), vib_button, FALSE, FALSE, 3);
     }
   }
 
+  gtk_box_pack_start(GTK_BOX(content_area), left_box, TRUE, TRUE, 3);
+  gtk_box_pack_start(GTK_BOX(content_area), right_box, FALSE, FALSE, 3);
 
   hildon_pannable_area_add_with_viewport(HILDON_PANNABLE_AREA(pannable_area), content_area); 
   gtk_container_add(GTK_CONTAINER(gtk_dialog_get_content_area(GTK_DIALOG(dialog))), pannable_area);
@@ -183,8 +187,14 @@ get_profile_icon_name(const gchar* profile_name)
   gchar* icon_name = NULL;
   keyFile = g_key_file_new();
   filename = g_strconcat (g_get_home_dir(), PROFILESX_PLUGIN_SETTINGS_FILE, NULL);
-  g_key_file_load_from_file (keyFile, filename, G_KEY_FILE_KEEP_COMMENTS, NULL);
-  icon_name = g_key_file_get_string(keyFile, profile_name, "icon", NULL);
+  g_key_file_load_from_file(keyFile, filename, G_KEY_FILE_KEEP_COMMENTS, NULL);
+  if(g_key_file_load_from_file(keyFile, filename, G_KEY_FILE_NONE, NULL))
+  {
+    if(g_key_file_has_key(keyFile, profile_name, "icon", NULL))
+    {
+      icon_name = g_key_file_get_string(keyFile, profile_name, "icon", NULL);
+    }
+  }
   g_key_file_free (keyFile); 
   g_free (filename); 
   return icon_name;
@@ -193,19 +203,23 @@ get_profile_icon_name(const gchar* profile_name)
 static void
 set_profile_status(ProfilesxStatusPlugin* plugin, const gchar* profile)
 {
-  GtkWidget *image;
-  image = gtk_image_new_from_icon_name("general_profile", 48);
-  gtk_image_set_pixel_size(GTK_IMAGE(image), 48);
   gchar* icon_name = get_profile_icon_name(profile);
   if(icon_name != NULL)
   {
-    GdkPixbuf *pixbuf = gtk_icon_theme_load_icon (gtk_icon_theme_get_default (), icon_name, 18, 0, NULL);
+    GdkPixbuf *pixbuf = gtk_icon_theme_load_icon(gtk_icon_theme_get_default(), icon_name, 18, GTK_ICON_LOOKUP_NO_SVG, NULL);
     if(pixbuf==NULL)
     {
-      GtkWidget* image = gtk_image_new_from_file(icon_name);
-      pixbuf = gtk_image_get_pixbuf(GTK_IMAGE(image));
-      hd_status_plugin_item_set_status_area_icon (HD_STATUS_PLUGIN_ITEM (plugin), pixbuf);
-      g_object_unref(image);  
+      pixbuf = gdk_pixbuf_new_from_file(icon_name,NULL);
+    }
+    if(pixbuf==NULL)
+    {
+      gchar* full_file_icon_name = g_strdup_printf("/usr/share/icons/hicolor/18x18/hildon/%s.png", icon_name);
+      pixbuf = gdk_pixbuf_new_from_file(full_file_icon_name,NULL);
+      g_free(full_file_icon_name);
+    }
+    if(pixbuf==NULL)
+    {
+      hd_status_plugin_item_set_status_area_icon (HD_STATUS_PLUGIN_ITEM (plugin), NULL);
     }
     else
     {
@@ -218,11 +232,6 @@ set_profile_status(ProfilesxStatusPlugin* plugin, const gchar* profile)
   {
     hd_status_plugin_item_set_status_area_icon (HD_STATUS_PLUGIN_ITEM (plugin), NULL);
   }
-  hildon_button_set_image(HILDON_BUTTON (plugin->priv->button), image);
-  hildon_button_set_style(HILDON_BUTTON (plugin->priv->button), HILDON_BUTTON_STYLE_PICKER);
-  hildon_button_set_alignment(HILDON_BUTTON(plugin->priv->button), 
-			      0, 0,
-			      1, 1);
   hildon_button_set_value(HILDON_BUTTON(plugin->priv->button), 
 			  get_profile_display_name(profile));
 }
@@ -237,6 +246,7 @@ handle_profile_changed(DBusGProxy *object,
 {
   gchar* new_profile = profile_get_profile();
   set_profile_status(plugin, new_profile);
+  g_free(new_profile);
 }
 
 static void
@@ -306,6 +316,66 @@ profilesx_status_plugin_class_init(ProfilesxStatusPluginClass* klass)
   g_type_class_add_private(klass, sizeof (ProfilesxStatusPluginPrivate));
 }
 
+static void
+profilesx_hide_profile_button(GtkWidget* widget, gpointer data)
+{
+  if(g_strcmp0(G_OBJECT_CLASS_NAME(G_OBJECT_GET_CLASS(G_OBJECT(widget))),
+	       "ProfilesStatusMenuItem")==0)
+  {
+    gtk_widget_hide(widget);
+  }
+}
+
+static void
+profilesx_show_profile_button(GtkWidget* widget, gpointer data)
+{
+  if(g_strcmp0(G_OBJECT_CLASS_NAME(G_OBJECT_GET_CLASS(G_OBJECT(widget))),
+	       "ProfilesStatusMenuItem")==0)
+  {
+    gtk_widget_show(widget);
+  }
+}
+
+static GtkWidget*
+profilesx_find_HDStatusMenuBox(GtkWidget* widget)
+{
+  
+  const gchar* class_name = G_OBJECT_CLASS_NAME(G_OBJECT_GET_CLASS(G_OBJECT(widget)));
+  GtkWidget* w = widget;
+  while(w != NULL && g_strcmp0(class_name, "HDStatusMenuBox")!=0)
+  {
+    w = gtk_widget_get_parent(w);
+    class_name = G_OBJECT_CLASS_NAME(G_OBJECT_GET_CLASS(G_OBJECT(w)));
+  }
+  return w;
+}
+
+static void
+hide_original_profile_button(ProfilesxStatusPlugin* plugin, gpointer data)
+{
+   GtkWidget* container = profilesx_find_HDStatusMenuBox(plugin->priv->button);
+
+   if(container != NULL)  
+   {  
+     gtk_container_foreach(GTK_CONTAINER(container),  
+			   (GtkCallback)(profilesx_hide_profile_button),  
+			   NULL);  
+   }  
+}
+
+static void
+show_original_profile_button(ProfilesxStatusPlugin* plugin, gpointer data)
+{
+  GtkWidget* container = profilesx_find_HDStatusMenuBox(plugin->priv->button);
+  
+  if(container != NULL)  
+  {  
+    gtk_container_foreach(GTK_CONTAINER(container),  
+			  (GtkCallback)(profilesx_show_profile_button),  
+			  NULL);  
+  }  
+}
+
 static void
 profilesx_status_plugin_init(ProfilesxStatusPlugin* plugin)
 {
@@ -318,8 +388,14 @@ profilesx_status_plugin_init(ProfilesxStatusPlugin* plugin)
 
   hildon_button_set_title(HILDON_BUTTON(plugin->priv->button), dgettext("osso-profiles", "profi_ti_menu_plugin"));
   g_signal_connect(plugin->priv->button, "clicked", G_CALLBACK(show_profile_selection_dlg), plugin);
-  gtk_widget_show_all(plugin->priv->button);
-
+  g_signal_connect(plugin, "unrealize", G_CALLBACK(show_original_profile_button), NULL); 
+  GtkWidget *image;
+  image = gtk_image_new_from_icon_name("general_profile", HILDON_ICON_SIZE_FINGER);
+  hildon_button_set_image(HILDON_BUTTON (plugin->priv->button), image);
+  hildon_button_set_style(HILDON_BUTTON (plugin->priv->button), HILDON_BUTTON_STYLE_PICKER);
+  hildon_button_set_alignment(HILDON_BUTTON(plugin->priv->button), 
+			      0, 0,
+			      1, 1);
   gchar* profile = profile_get_profile();
   if(profile)
   {
@@ -327,5 +403,7 @@ profilesx_status_plugin_init(ProfilesxStatusPlugin* plugin)
     g_free(profile);
   }
   gtk_container_add(GTK_CONTAINER(plugin), plugin->priv->button);
+  g_signal_connect(plugin, "realize", G_CALLBACK(hide_original_profile_button), NULL); 
+  gtk_widget_show_all(plugin->priv->button);
   gtk_widget_show(GTK_WIDGET(plugin));
 }
